@@ -172,7 +172,7 @@ g_libproxy_resolver_lookup (GProxyResolver  *iresolver,
   gchar **proxies;
 
   task = g_task_new (resolver, cancellable, NULL, NULL);
-  g_task_set_source_tag (task, g_libproxy_resolver_lookup);
+  g_task_set_name (task, "[glib-networking] g_libproxy_resolver_lookup");
   g_task_set_task_data (task, g_strdup (uri), g_free);
   g_task_set_return_on_cancel (task, TRUE);
 
@@ -194,6 +194,7 @@ g_libproxy_resolver_lookup_async (GProxyResolver      *resolver,
 
   task = g_task_new (resolver, cancellable, callback, user_data);
   g_task_set_source_tag (task, g_libproxy_resolver_lookup_async);
+  g_task_set_name (task, "[glib-networking] g_libproxy_resolver_lookup_async");
   g_task_set_task_data (task, g_strdup (uri), g_free);
   g_task_set_return_on_cancel (task, TRUE);
   g_task_run_in_thread (task, get_libproxy_proxies);
@@ -206,6 +207,7 @@ g_libproxy_resolver_lookup_finish (GProxyResolver     *resolver,
                                    GError            **error)
 {
   g_return_val_if_fail (g_task_is_valid (result, resolver), NULL);
+  g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == g_libproxy_resolver_lookup_async, NULL);
 
   return g_task_propagate_pointer (G_TASK (result), error);
 }
@@ -233,7 +235,7 @@ void
 g_libproxy_resolver_register (GIOModule *module)
 {
   g_libproxy_resolver_register_type (G_TYPE_MODULE (module));
-  if (module == NULL)
+  if (!module)
     g_io_extension_point_register (G_PROXY_RESOLVER_EXTENSION_POINT_NAME);
   g_io_extension_point_implement (G_PROXY_RESOLVER_EXTENSION_POINT_NAME,
                                   g_libproxy_resolver_get_type(),
